import { BaseEvent } from '#application/base/baseEvent'
import { CharacterHair } from '#entities/characterHair'
import characterRepository from '#repositories/characterRepository'

export default class CharacterHairCreateEvent extends BaseEvent {
  public listen(): void {
    this.socket.on('gm:characterHair:create', this.handleEvent.bind(this))
  }

  private async handleEvent(data: undefined, callback: (response: boolean, characterType?: any) => void): Promise<void> {
    try {
      const character = await characterRepository.getById(this.socket.characterId as number)
      if (!character) return callback(false)

      if (character.role !== 'gm') {
        return callback(false)
      }

      const newCharacterHair = new CharacterHair()
      await newCharacterHair.setName('New hair').save()

      callback(true, newCharacterHair)
    } catch (error) {
      console.error('Error creating character hair:', error)
      callback(false)
    }
  }
}
